@@ -7,16 +7,20 @@
 
 """ Implementation for HTTP upload method. """
 
+from http.client import HTTPSConnection
+
 from . import http
 
 
-def upload(fqdn, login, incoming, files_to_upload, debug, dummy, progress=0):
+def upload(
+        fqdn, login, incoming, files_to_upload, debug, dummy,
+        progress=0, protocol="https", connection_class=HTTPSConnection):
     return http.upload(
             fqdn, login, incoming, files_to_upload, debug, dummy,
-            progress, protocol="https")
+            progress, protocol=protocol, connection_class=connection_class)
 
 
-# Copyright © 2015–2019 Ben Finney <bignose@debian.org>
+# Copyright © 2015–2021 Ben Finney <bignose@debian.org>
 # Copyright © 2007 Thomas Viehmann <tv@beamnet.de>
 #
 # This is free software: you may copy, modify, and/or distribute this work
